@@ -26,6 +26,8 @@
 #include <QCloseEvent>
 #include <QMenuBar>
 
+#define OS_FORCEROTATION "forcerotation = 1"
+
 FastSMSWidget::FastSMSWidget(QWidget *parent) :
         QWidget(parent),
         ui(new Ui::FastSMSWidget)
@@ -44,7 +46,6 @@ FastSMSWidget::FastSMSWidget(QWidget *parent) :
     m_bDictionaryUpdated = false;
     m_dictionary = NULL;
 
-
     qDebug() << "Load settings...";
     //Setup and Load Settings
     loadSettings(true);
@@ -97,24 +98,25 @@ void FastSMSWidget::closeEvent(QCloseEvent *event)
 
         qDebug() << "Curr orientation:" << m_sCurrOrientation;
 
-#if defined(Q_WS_MAEMO_5)
-        //If not landscape, need to return to landscape view
-        if(m_sCurrOrientation.compare(Core::ORIENTATION_LANDSCAPE) != 0)
-        {
-            setAttribute(Qt::WA_Maemo5LandscapeOrientation, true);
 
-            hide();
-            showMaximized();
+#if defined(Q_WS_MAEMO_5)
+        if(!m_bOSForceAutorotation)
+        {
+            //If not landscape, need to return to landscape view
+            if(m_sCurrOrientation.compare(Core::ORIENTATION_LANDSCAPE) != 0)
+            {
+                setAttribute(Qt::WA_Maemo5LandscapeOrientation, true);
+
+                hide();
+                showMaximized();
+            }
         }
 #endif
 
+
         hide();
         qDebug() << "hided";
-        //sleep(0.8);
-
-        //test
         m_textProcessor->commit();
-        //
     }
     else
     {
@@ -157,19 +159,22 @@ void FastSMSWidget::orientationChanged(QString sOrientation)
     if(m_bStandalone)
         return;
 
-    if(isVisible() && m_sCurrOrientation.compare(sOrientation) != 0)
+    if(!m_bOSForceAutorotation)
     {
-        qDebug() << "Orientation changed:" << sOrientation;
-
-        if(sOrientation.compare(Core::ORIENTATION_PORTRAIT) == 0 ||
-           sOrientation.compare(Core::ORIENTATION_LANDSCAPE) == 0)
+        if(isVisible() && m_sCurrOrientation.compare(sOrientation) != 0)
         {
-            m_sCurrOrientation = sOrientation;
-            hide();
-            showMaximized();
+            qDebug() << "Orientation changed:" << sOrientation;
+
+            if(sOrientation.compare(Core::ORIENTATION_PORTRAIT) == 0 ||
+               sOrientation.compare(Core::ORIENTATION_LANDSCAPE) == 0)
+            {
+                m_sCurrOrientation = sOrientation;
+                hide();
+                showMaximized();
+            }
+            else
+                qWarning() << "Unknown orientation:" << sOrientation;
         }
-        else
-            qWarning() << "Unknown orientation:" << sOrientation;
     }
 }
 
@@ -196,6 +201,34 @@ void FastSMSWidget::openOptionDialog()
 
 void FastSMSWidget::loadSettings(bool bLoadDictionary)
 {
+    //Check if CSSU autorotation is ON
+    m_bOSForceAutorotation = false;
+    QFile *fTransition = new QFile("/etc/hildon/theme/transitions.ini");
+
+    //fallback
+    if(!fTransition->exists())
+    {
+        delete fTransition;
+        fTransition = new QFile("/usr/share/hildon-desktop/transitions.ini");
+    }
+    if(!fTransition->open(QIODevice::ReadOnly))
+        qWarning() << "Can't open tranistions.ini";
+    else
+    {
+        QTextStream in(fTransition);
+
+        while (!in.atEnd())
+        {
+            QString line = in.readLine();
+            if(line.compare(OS_FORCEROTATION) == 0)
+            {
+                m_bOSForceAutorotation = true;
+                qDebug() << "Forced Autorotation is ON";
+            }
+        }
+    }
+    delete fTransition;
+
     QSettings settings;
 
     //Language
@@ -299,7 +332,9 @@ void FastSMSWidget::surroundRequest(const QString &text)
     if(m_bStandalone)
         setStandalone(false);
 
-    m_sCurrOrientation = getDeviceOrientation();
+    if(!m_bOSForceAutorotation)
+        m_sCurrOrientation = getDeviceOrientation();
+
     m_textProcessor->setText(text);
     showMaximized();
     raise();
